summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorYu-Hsuan Hsu <yuhsuan@chromium.org>2021-02-18 12:42:52 +0800
committerCommit Bot <commit-bot@chromium.org>2021-02-19 03:39:02 +0000
commitc983f46d0dff5e0fa79dcc7deb95ab2bc59f808d (patch)
treee6670e7f7dc6dceb543bd6498b28fc9c80e97a8d
parent6062f0962737cbf3c071ae15ba2bc2353b3096a1 (diff)
downloadadhd-c983f46d0dff5e0fa79dcc7deb95ab2bc59f808d.tar.gz
CRAS: stream_list - loosen the criteria of RTC stream detection
Some services like https://appr.tc/?debug=loopback may create output streams more than 1 second later than create the input stream. Increate the threshold to 10s so that we should be able to catch all RTC streams. BUG=b:177185438 TEST=Verified the RTC streams can be detected correctly. Change-Id: If25d3bf4ce2550226bb4cc6eb3ef1d94ac0c1be7 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/adhd/+/2703227 Commit-Queue: Yu-Hsuan Hsu <yuhsuan@chromium.org> Tested-by: Yu-Hsuan Hsu <yuhsuan@chromium.org> Reviewed-by: Cheng-Yi Chiang <cychiang@chromium.org>
-rw-r--r--cras/src/server/stream_list.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/cras/src/server/stream_list.c b/cras/src/server/stream_list.c
index 776fbf1f..04ef9fe1 100644
--- a/cras/src/server/stream_list.c
+++ b/cras/src/server/stream_list.c
@@ -11,10 +11,10 @@
#include "utlist.h"
/*
* If the time difference of two streams is short than 1s, they may be the RTC
* streams.
*/
-static const struct timespec RTC_STREAM_THRESHOLD = { 1, 0 };
+static const struct timespec RTC_STREAM_THRESHOLD = { 10, 0 };
struct stream_list {
struct cras_rstream *streams;
@@ -11,10 +11,10 @@
#include "utlist.h"
/*
- * If the time difference of two streams is short than 1s, they may be the RTC
+ * If the time difference of two streams is short than 10s, they may be the RTC
* streams.
*/